AppMeteringControllerApi class

Constructors

AppMeteringControllerApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDeviceDataDetails(int meterId) Future<ConsumptionAppDTO?>
Parameters:
getDeviceDataDetailsWithHttpInfo(int meterId) Future<Response>
Performs an HTTP 'GET /app/metering/{meterId}' operation and returns the Response. Parameters:
getDevices() Future<List<DeviceMobileDetailDTO>?>
getDevicesWithHttpInfo() Future<Response>
Performs an HTTP 'GET /app/metering/' operation and returns the Response.
getDeviceValues(int deviceId, String channel, String to, {bool? manualOnly}) Future<HistoryConsumptionAppDTO?>
Parameters:
getDeviceValuesWithHttpInfo(int deviceId, String channel, String to, {bool? manualOnly}) Future<Response>
Performs an HTTP 'GET /app/metering/{deviceId}/values/{channel}' operation and returns the Response. Parameters:
insertValues(int deviceId, AppValueInsertDTO appValueInsertDTO) Future<void>
Parameters:
insertValuesWithHttpInfo(int deviceId, AppValueInsertDTO appValueInsertDTO) Future<Response>
Performs an HTTP 'POST /app/metering/{deviceId}/values' operation and returns the Response. Parameters:
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited