ConsumptionAppDTO class

Constructors

ConsumptionAppDTO({int? id, String? type, String? category, String? categoryCode, String? typeCode, String? modelName, String? name, List<String> objectNames = const [], Map<String, ValueDTO> lastValues = const {}, DateTime? lastValueReceived, ConsumptionAppDTOReceptionStatusEnum? receptionStatus})
Returns a new ConsumptionAppDTO instance.

Properties

category String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
categoryCode String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id int?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
lastValueReceived DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
lastValues Map<String, ValueDTO>
getter/setter pair
modelName String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
name String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
objectNames List<String>
getter/setter pair
receptionStatus ConsumptionAppDTOReceptionStatusEnum?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
typeCode String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) ConsumptionAppDTO?
Returns a new ConsumptionAppDTO instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<ConsumptionAppDTO>?
mapFromJson(dynamic json) Map<String, ConsumptionAppDTO>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<ConsumptionAppDTO>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.